km3modules\.k40\.CoincidenceFinder
==================================

.. currentmodule:: km3modules.k40

.. autoclass:: CoincidenceFinder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CoincidenceFinder.__init__
      ~CoincidenceFinder.add
      ~CoincidenceFinder.configure
      ~CoincidenceFinder.finish
      ~CoincidenceFinder.get
      ~CoincidenceFinder.mongincidence
      ~CoincidenceFinder.pre_finish
      ~CoincidenceFinder.process
      ~CoincidenceFinder.require
   
   

   
   
   